rust python3 ffi
================

[Rust](http://www.rust-lang.org/) FFI declarations for Python 3.
Supports the PEP 384 stable ABI for Python 3.4 or higher.

---

This [cargo -sys package](http://doc.crates.io/build-script.html#*-sys-packages) provides `python3` declarations.
Licensed under the Python license (see `LICENSE`).

For a safe high-level API, see [PyO3](https://github.com/PyO3/PyO3).

Documentation for the python API is available on [https://docs.python.org/3/c-api/].

